@@ -1,15 +1,17 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lo">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="lo">
 <context>
     <name>desktop</name>
     <message>
         <location filename="Desktop Entry]Name" line="0"/>
         <source>Deepin Downloader</source>
-        <translation>Deepin ດາວໂຫຼດ</translation>
+        <translation>ເຄື່ອງດາວໂຫລດ</translation>
     </message>
     <message>
         <location filename="Desktop Entry]GenericName" line="0"/>
         <source>Downloader</source>
-        <translation>ໂປຣແກຣມດາວໂຫຼດ</translation>
+        <translation>ເຄື່ອງດາວໂຫລດ</translation>
     </message>
 </context>
 </TS>
